@@ -71,7 +71,7 @@ room {
 		ru = [[{$fmt c|Добро пожаловать в режим обучения INSTEAD.}^^
 	Игра состоит из сцен. Каждая сцена игры имеет описание,
 	состоящее из статической и динамической части. Динамическая часть включает объекты,
-	персонажей и т.д. С динамической частью игрок может взаимодействовать с помощью мыши, 
+	персонажей и т.д. С динамической частью игрок может взаимодействовать с помощью мыши,
 	нажимая на подсвеченные ссылки.^^
 
 	Данная сцена называется "Обучение" и сейчас Вы читаете статическую часть её описания.
@@ -169,7 +169,7 @@ room {
 		uk = [[{$fmt c|Вітаємо в режимі навчання INSTEAD.}^^
 	Гра складається зі сцен. Кожна сцена гри має опис,
 	що складається зі статичної та динамічної частини. Динамічна частина включає об'єкти,
-	персонажі й т.і. З динамічною частиною гравець може взаємодіяти за допомогою миші, 
+	персонажі й т.і. З динамічною частиною гравець може взаємодіяти за допомогою миші,
 	нажимаючи на підсвічені посилання.^^
 
 	Дана сцена має назву "Навчання" і зараз Ви читаєте статичну частину її опису.
@@ -392,13 +392,13 @@ room {
 		um objeto com as setas direcionais e pressionar "Enter" para interagir com ele.]],
 
 		uk = [[Урок 1. Взаємодія з об`єктами^^
-		Продовжимо урок. Зараз Ви знаходитесь в кімнаті. Візьміть обидва предмети, 
+		Продовжимо урок. Зараз Ви знаходитесь в кімнаті. Візьміть обидва предмети,
 		котрі Ви бачите. Нагадаємо, що для цього Ви можете просто
 		використовувати мишу. Якщо Вам зручніше використовувати клавіатуру -- можна
 		обрати потрібний предмет за допомогою клавіш зі стрілками и натиснути "Введення" для
 		взаємодії з ними.]],
 	};
-}:with { 'paper', 'pencil', 
+}:with { 'paper', 'pencil',
 	obj {
 		nam = '#cont';
 		dsc = L {
@@ -498,9 +498,9 @@ room {
 	dsc = L {
 		ru = [[Урок 2. Использование инвентаря - Часть I^^
 		Теперь у Вас появились предметы, которые можно использовать или изучать.
-		Для этого предназначен инвентарь. Вы можете посмотреть на любой предмет 
-		инвентаря дважды щелкнув мышью по этому предмету. То же самое можно 
-		сделать с помощью клавиатуры: нажмите "Tab", чтобы переключиться на панель 
+		Для этого предназначен инвентарь. Вы можете посмотреть на любой предмет
+		инвентаря дважды щелкнув мышью по этому предмету. То же самое можно
+		сделать с помощью клавиатуры: нажмите "Tab", чтобы переключиться на панель
 		инвентаря, выберите нужный предмет и дважды
 		нажмите "Ввод". Чтобы вернуться назад к описанию сцены, нажмите "Tab" еще раз.^^
 
@@ -568,9 +568,9 @@ room {
 
 		uk = [[Урок 2. Використання інвентарю - Частина I^^
 		Тепер у Вас з'явилися предмети, котрі можно використовувати чи вивчати.
-		Для цього призначений інвентар. Ви можете подивитися на будь-який предмет 
+		Для цього призначений інвентар. Ви можете подивитися на будь-який предмет
 		інвентарю двічи клацнувши мишею по цьому предмету. Те ж саме можна
-		зробити за допомогою клавіатури: нажміть "Tab", щоб перемкнутися на панель 
+		зробити за допомогою клавіатури: нажміть "Tab", щоб перемкнутися на панель
 		інвентарю, оберіть потрібний предмет і двічі
 		нажміть "Введення". Щоб повернутися назад до опису сцени, нажмить "Tab" ще раз.^^
 
@@ -761,19 +761,19 @@ room {
 	end;
 	dsc = L {
 		ru = [[Урок 3. Использование инвентаря - Часть II^^
-		Вы можете действовать предметами инвентаря на другие предметы сцены или инвентаря. 
-		В этой комнате вы увидите стол. Попробуйте воздействовать карандашом на стол.^^ 
+		Вы можете действовать предметами инвентаря на другие предметы сцены или инвентаря.
+		В этой комнате вы увидите стол. Попробуйте воздействовать карандашом на стол.^^
 
 		Для этого нажмите мышью на карандаш, а затем на стол. То же самое можно сделать
 		с помощью клавиатуры: используя клавиши "Tab", "Ввод" и "стрелки".^^
-  
+
 		Затем посмотрите на стол. И не забудьте взять яблоко, оно нам пригодится в следующем уроке.]],
 
 		en = [[Lesson 3. Using the inventory — Part II^^
 		You can act with inventory objects on other objects of the scene or inventory. In this room you'll see a desk. Try using pencil on it.^^
 
 		To do that click mouse on the pencil, then click on the desk. Or you can do the same with "Tab", "enter" and arrows.^^
-  
+
 		Then look at the table. And don't forget to take the apple, you'll need it in the next lesson.]],
 
 		de = [[3. Lektion: Benutzung des Inventars – 2. Teil^^
@@ -797,12 +797,12 @@ room {
 		La necesitarás para la próxima lección.]],
 
 		fr = [[Leçon nº 3. Utiliser l'inventaire — Partie II^^
-		Vous pouvez faire agir les objets de l'inventaire sur d'autres objets de la scène ou de l'inventaire. 
+		Vous pouvez faire agir les objets de l'inventaire sur d'autres objets de la scène ou de l'inventaire.
 		Dans cette salle, vous verrez un bureau. Essayez d'utiliser un crayon sur lui.^^
 
 		Pour ce faire, cliquez avec la souris sur le crayon, puis cliquez sur le bureau.
 		Ou alors, vous pouvez faire la même chose au clavier avec « Tab », « Entrée » et les flèches.^^
-  
+
 		Il suffit ensuite de regarder le bureau pour voir le résultat. Et n'oubliez pas de prendre la pomme,
 		vous en aurez besoin dans la prochaine leçon.]],
 
@@ -835,17 +835,17 @@ room {
 
 		Para isso clique com o mouse no lápis, então clique na escrivaninha.
 		Ou você pode fazer o mesmo com "Tab", "enter" e as setas do teclado.^^
-  
+
 		Então examine a mesa. E não esqueça de pegar a maçã, você precisará dela
 		na próxima lição.]],
 
 		uk = [[Урок 3. Використання інвентаря - Частина II^^
-		Ви можете задіяти предмети інвентарю на інші предмети сцени чи інвентарю. 
-		В цій комнаті ви бачите стіл. Спробуйте задіяти олівець на стіл.^^ 
+		Ви можете задіяти предмети інвентарю на інші предмети сцени чи інвентарю.
+		В цій комнаті ви бачите стіл. Спробуйте задіяти олівець на стіл.^^
 
 		Для цього клацніть мишей на олівець, а потім на стіл. Те ж саме можна зробити
 		за допомогою клавіатури: використовуючи клавіши "Tab", "Введення" й "стрілки".^^
-  
+
 		Потім подивіться на стіл. І не забудьте взяти яблуко, воно нам знадобиться в наступному уроці.]],
 	};
 }:with {
@@ -983,14 +983,14 @@ room {
 		uk = [[Урок 4. Використання інвентарю - Частина III^^
 		Гаразд, тепер вивчимо ще декілька дій з предметами.^^
 
-		По-перше, напішить що-небудь на папері. Для цього нажміть мишею 
+		По-перше, напішить що-небудь на папері. Для цього нажміть мишею
 		на олівець, а потім на папір. Після цього ви можете подивитись
 		на папір, щоб побачити ваш запис.^^
 
-		По-друге, з'їште яблуко, котре Ви взяли зі столу в попередній кімнаті. 
+		По-друге, з'їште яблуко, котре Ви взяли зі столу в попередній кімнаті.
 		Для цього двічи клацніть по яблуку в інвентарі.^^
 
-		Всі описані дії можна виконати за допомогою клавіатури так само, 
+		Всі описані дії можна виконати за допомогою клавіатури так само,
 		як показано в попередньому уроці.]],
 	};
 }:with {
@@ -1045,11 +1045,11 @@ room {
 	end;
 	dsc = L {
 		ru = [[Урок 5. Перемещение - Часть I^^
-		Теперь изучим переходы между комнатами. В этой комнате Вы видите пять 
+		Теперь изучим переходы между комнатами. В этой комнате Вы видите пять
 		дополнительных ссылок с номерами уроков. Перейдите на урок 6. ^^
 
 		Для этого нажмите мышью на соответствующую ссылку. Вы также можете воспользоваться
-		клавиатурой -- выберите нужную ссылку с помощью клавиш со стрелками 
+		клавиатурой -- выберите нужную ссылку с помощью клавиш со стрелками
 		и нажмите "Ввод" для перехода.]],
 
 		en = [[Lesson 5. Moving — Part I^^
@@ -1096,11 +1096,11 @@ room {
 		Clique no link apropriado ou use o teclado — selecione o link com as setas e tecle "Enter".]],
 
 		uk = [[Урок 5. Переміщення - Частина I^^
-		Тепер вивчимо переходи між кімнатами. В цій кімнаті Ви бачите п'ять 
+		Тепер вивчимо переходи між кімнатами. В цій кімнаті Ви бачите п'ять
 		допоміжних посилань з номерами уроків. Перейдіть на урок 6. ^^
 
 		Для цього натисніть мишею на відповідне посилання. Ви також можете використати
-		клавіатуру -- виберіть потрібне посилання за допомогою клавіш зі стрілками 
+		клавіатуру -- виберіть потрібне посилання за допомогою клавіш зі стрілками
 		та нажміть "Введення" для переходу.]],
 	};
 	way = { 'r1', 'r2', 'r3', 'r4', 'r6'},
@@ -1181,8 +1181,8 @@ room {
 		uk = 'Останній урок',
 	};
 	dsc = L {
-		ru = [[Вы можете выбирать игру, сохранять и загружать её состояние и выполнять 
-		другие действия с помощью меню. Для вызова меню нажмите клавишу "Esc" или 
+		ru = [[Вы можете выбирать игру, сохранять и загружать её состояние и выполнять
+		другие действия с помощью меню. Для вызова меню нажмите клавишу "Esc" или
 		нажмите мышью на символ меню (справа снизу).^^
 		Теперь Вы готовы к игре. Удачи!!!^^
 		Игры для INSTEAD можно скачать здесь: {$fmt u|https://instead-hub.github.io}^^
@@ -1235,7 +1235,7 @@ room {
 		O tutorial usa o tema "Instead game-engine" de svenzzon.]],
 
 		uk = [[Ви можете вибирати гру, зберігати та завантажувати її стан і виконувати
-		інші дії за допомогою меню. Для виклику меню натисніть клавішу "Esc" або 
+		інші дії за допомогою меню. Для виклику меню натисніть клавішу "Esc" або
 		натисніть мишею на символ меню (справа знизу).^^
 		Тепер Ви готові до гри. Хай щастить!!!^^
 		Ігри для INSTEAD можно завантажити тут: {$fmt u|https://instead-hub.github.io}^^
@@ -1527,7 +1527,7 @@ room {
 		fr = 'Voir les {@ walk help2|paramètres de la ligne de commande}.',
 		it = 'Vedi {@ walk help2|parametri della linea di comando}.',
 		nl = 'Zie {@ walk help2|commandoregel parameters}.',
-		pt = 'Ver {@ walk help2|parâmetros de linha de comando}.', 
+		pt = 'Ver {@ walk help2|parâmetros de linha de comando}.',
 		uk = 'Подивитись {@ walk help2|параметри командного рядка}.',
 	};
 }
@@ -1553,7 +1553,7 @@ room {
 	-game <игра> - выбор игры;^
 	-themespath <путь> - дополнительный путь к темам;^
 	-gamespath <путь> - дополнительный путь к играм;^
-	-windows - оконный режим;^
+	-window - оконный режим;^
 	-fullscreen - полноэкранный режим;^
 	-noautosave - отключить автосохранение/автозагрузку;^
 	-encode <game.lua> [encoded.lua] - закодировать исходный текст lua (используйте doencfile для загрузки такого файла);^
@@ -1665,7 +1665,7 @@ room {
 	-game <гра> - вибір гри;^
 	-themespath <шлях> - додатковий шлях до тем;^
 	-gamespath <шлях> - додатковий шлях до ігр;^
-	-windows - віконний режим;^
+	-window - віконний режим;^
 	-fullscreen - повноекранний режим;^
 	-noautosave - відключити автозбереження/автозагрузку;^
 	-encode <game.lua> [encoded.lua] - закодувати вихідний текст lua (використовуйте doencfile для загрузки такого файла);^
