@@ -259,7 +259,19 @@ int _shrinkSurfaceY(SDL_Surface * src, SDL_Surface * dst, int factorx, int facto
 	return (0);
 }
 
-/*! 
+int _greatestCommonDivisor(int n1, int n2) {
+	//Using Euclid's algorithm
+	int r = 1;
+	while (n2 > 0) {
+		r = n2;
+		n2 = n1 % n2;
+		n1 = r;
+	}
+
+	return r;
+}
+
+/*!
 \brief Internal 32 bit Zoomer with optional anti-aliasing by bilinear interpolation.
 
 Zooms 32 bit RGBA/ABGR 'src' surface to 'dst' surface.
@@ -277,6 +289,14 @@ Assumes dst surface was allocated with the correct dimensions.
 int _zoomSurfaceRGBA(SDL_Surface * src, SDL_Surface * dst, int flipx, int flipy, int smooth)
 {
 	int x, y, sx, sy, ssx, ssy, *sax, *say, *csax, *csay, *salast, csx, csy, ex, ey, cx, cy, sstep, sstepx, sstepy;
+	/*
+	 * Variables for applying scale factors
+	 * dx, dy -- deltas to apply each fx, fy pixels
+	 * mx, my -- Multiplier for source pixels (see below)
+	 * fx, fy -- Multiplier for target pixels
+	 * nxd, nyd -- next pixel to apply delta on
+	 */
+	int dx = 0, dy = 0, mx = 1, my = 1, fx = 0, fy = 0, nxd = 0, nyd = 0;
 	tColorRGBA *c00, *c01, *c10, *c11;
 	tColorRGBA *sp, *csp, *dp;
 	int spixelgap, spixelw, spixelh, dgap, t1, t2;
@@ -300,9 +320,43 @@ int _zoomSurfaceRGBA(SDL_Surface * src, SDL_Surface * dst, int flipx, int flipy,
 	if (smooth) {
 		sx = (int) (65536.0 * (float) spixelw / (float) (dst->w - 1));
 		sy = (int) (65536.0 * (float) spixelh / (float) (dst->h - 1));
+
+		if (dst->w > src->w) {
+			mx = _greatestCommonDivisor(dst->w - 1, spixelw);
+			fx = (dst->w - 1) / mx;
+			mx = spixelw / mx;
+		}
+
+		if (dst->h > src->h) {
+			my = _greatestCommonDivisor(dst->h - 1, spixelh);
+			fy = (dst->h - 1) / my;
+			my = spixelh / my;
+		}
 	} else {
 		sx = (int) (65536.0 * (float) (src->w) / (float) (dst->w));
 		sy = (int) (65536.0 * (float) (src->h) / (float) (dst->h));
+
+		if (dst->w > src->w) {
+			mx = _greatestCommonDivisor(dst->w, src->w);
+			fx = dst->w / mx;
+			mx = src->w / mx;
+		}
+
+		if (dst->h > src->h) {
+			my = _greatestCommonDivisor(dst->h, src->h);
+			fy = dst->h / my;
+			my = src->h / my;
+		}
+	}
+
+	if (dst->w > src->w) {
+		nxd = fx;
+		dx = 65536 * mx - sx * fx;
+	}
+
+	if (dst->h > src->h) {
+		nyd = fy;
+		dy = 65536 * my - sy * fy;
 	}
 
 	/* Maximum scaled source size */
@@ -315,6 +369,12 @@ int _zoomSurfaceRGBA(SDL_Surface * src, SDL_Surface * dst, int flipx, int flipy,
 	for (x = 0; x <= dst->w; x++) {
 		*csax = csx;
 		csax++;
+
+		if (x + 1 == nxd) {
+			csx += dx;
+			nxd += fx;
+		}
+
 		csx += sx;
 
 		/* Guard from overflows */
@@ -329,6 +389,13 @@ int _zoomSurfaceRGBA(SDL_Surface * src, SDL_Surface * dst, int flipx, int flipy,
 	for (y = 0; y <= dst->h; y++) {
 		*csay = csy;
 		csay++;
+
+		if (y + 1 == nyd) {
+			csy += dy;
+			nyd += fy;
+		}
+
+
 		csy += sy;
 
 		/* Guard from overflows */
