@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2022 Peter Kosyh <p.kosyh at gmail.com>
+ * Copyright 2009-2024 Peter Kosyh <p.kosyh at gmail.com>
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation files
@@ -86,7 +86,7 @@ int system_clipboard(const char *text, char **buf)
 #ifdef SAILFISHOS
 static SDL_FingerID finger_mouse = 0;
 
-static void push_mouse_event(SDL_Event *sevent)
+static void touch_mouse_event(SDL_Event *sevent)
 {
 	SDL_Event event;
 	memset(&event, 0, sizeof(event));
@@ -116,6 +116,8 @@ extern void gfx_finger_pos_scale(float x, float y, int *ox, int *oy, int norm);
 #define INPUT_REP_DELAY_MS 500
 #define INPUT_REP_INTERVAL_MS 30
 
+#define GAMEPAD_TICKS 20
+
 #if defined(IOS) || defined(ANDROID)
 int HandleAppEvents(void *userdata, SDL_Event *event)
 {
@@ -169,7 +171,48 @@ int HandleAppEvents(void *userdata, SDL_Event *event)
 }
 #endif
 
+static gtimer_t gamepad_timer = NULL_TIMER;
 static SDL_GameController *gamepad = NULL;
+static int deadzone = 8192;
+
+const float MOUSE_SHIFT_MIN = 1.0;
+const float MOUSE_SHIFT_MAX = 10.0;
+
+static int gamepad_deadzone(SDL_GameController *g)
+{
+#if SDL_VERSION_ATLEAST(2,0,12)
+	switch (SDL_GameControllerGetType(g))
+	{
+	case SDL_CONTROLLER_TYPE_UNKNOWN:
+	case SDL_CONTROLLER_TYPE_XBOXONE:
+	case SDL_CONTROLLER_TYPE_XBOX360:
+	case SDL_CONTROLLER_TYPE_PS3:
+		return 10000;
+	case SDL_CONTROLLER_TYPE_PS4:
+	case SDL_CONTROLLER_TYPE_PS5:
+		return 4096;
+	case SDL_CONTROLLER_TYPE_NINTENDO_SWITCH_PRO:
+		return 8192; // Actual dead-zone should be closer to 10% of full-scale, but we use this to account for variances in 3rd-party controllers
+	case SDL_CONTROLLER_TYPE_VIRTUAL:
+		return 8192;
+	default:
+		return 8192;
+	}
+#else
+	return 8192;
+#endif
+}
+
+static int gamepad_mouse_shift(int axis_value) {
+	float range;
+	if (abs(axis_value) < deadzone)
+		return 0;
+	range = 32768.0 - deadzone;
+	if (axis_value > deadzone)
+		return MOUSE_SHIFT_MIN + (MOUSE_SHIFT_MAX - MOUSE_SHIFT_MIN) * (axis_value - deadzone) / range;
+	else
+		return -MOUSE_SHIFT_MIN + (MOUSE_SHIFT_MAX - MOUSE_SHIFT_MIN) * (axis_value + deadzone) / range;
+}
 
 static void gamepad_init(void)
 {
@@ -183,7 +226,9 @@ static void gamepad_init(void)
 		if (SDL_IsGameController(i)) {
 			gamepad = SDL_GameControllerOpen(i);
 			if (gamepad) {
-			        fprintf(stderr, "Found gamepad: %s\n", SDL_GameControllerName(gamepad));
+				fprintf(stderr, "Found gamepad: %s\n",
+					SDL_GameControllerName(gamepad));
+				deadzone = gamepad_deadzone(gamepad);
 				break;
 			} else {
 				fprintf(stderr, "Could not open gamepad %i: %s\n", i, SDL_GetError());
@@ -196,37 +241,130 @@ static void gamepad_init(void)
 
 static void gamepad_done(void)
 {
-	if(gamepad)
+	if(gamepad) {
+		gfx_del_timer(gamepad_timer);
 		SDL_GameControllerClose(gamepad);
+	}
 	if(SDL_WasInit(SDL_INIT_GAMECONTROLLER))
 		SDL_QuitSubSystem(SDL_INIT_GAMECONTROLLER);
 }
 
-static const char *gamepad_map(int button)
+static void gamepad_check_triggers(void)
 {
-	switch(button) {
-	case SDL_CONTROLLER_BUTTON_DPAD_UP:
-		return "up";
-	case SDL_CONTROLLER_BUTTON_DPAD_DOWN:
-		return "down";
-	case SDL_CONTROLLER_BUTTON_DPAD_LEFT:
-		return "left";
-	case SDL_CONTROLLER_BUTTON_DPAD_RIGHT:
-		return "right";
-	case SDL_CONTROLLER_BUTTON_A:
-		return "return";
-	case SDL_CONTROLLER_BUTTON_B:
-		return "space";
-	case SDL_CONTROLLER_BUTTON_X:
-		return "tab";
-	case SDL_CONTROLLER_BUTTON_START:
-		return "escape";
-	case SDL_CONTROLLER_BUTTON_LEFTSHOULDER:
-		return "page up";
-	case SDL_CONTROLLER_BUTTON_RIGHTSHOULDER:
-		return "page down";
+	SDL_Event event;
+	memset(&event, 0, sizeof(event));
+	event.type = SDL_MOUSEWHEEL;
+
+	int trigger_left = 0, trigger_right = 0;
+	trigger_left = SDL_GameControllerGetAxis(gamepad, SDL_CONTROLLER_AXIS_TRIGGERLEFT);
+	trigger_right = SDL_GameControllerGetAxis(gamepad, SDL_CONTROLLER_AXIS_TRIGGERRIGHT);
+
+	if (abs(trigger_left) > deadzone) {
+		event.wheel.y = 1;
+		SDL_PushEvent(&event);
+	} else if (abs(trigger_right) > deadzone) {
+		event.wheel.y = -1;
+		SDL_PushEvent(&event);
 	}
-	return "";
+}
+
+static int gamepad_timer_fn(int interval, void *p)
+{
+	SDL_Event event;
+	int axis_x = 0, axis_y = 0;
+
+	if (!gamepad)
+		return interval;
+
+	gamepad_check_triggers();
+
+	axis_x = SDL_GameControllerGetAxis(gamepad, SDL_CONTROLLER_AXIS_RIGHTX);
+	axis_y = SDL_GameControllerGetAxis(gamepad, SDL_CONTROLLER_AXIS_RIGHTY);
+
+	if (abs(axis_x) <= deadzone && abs(axis_y) <= deadzone) {
+		axis_x = SDL_GameControllerGetAxis(gamepad, SDL_CONTROLLER_AXIS_LEFTX);
+		axis_y = SDL_GameControllerGetAxis(gamepad, SDL_CONTROLLER_AXIS_LEFTY);
+	}
+
+	if (abs(axis_x) > deadzone || abs(axis_y) > deadzone) {
+		memset(&event, 0, sizeof(event));
+		event.type = SDL_MOUSEMOTION;
+		gfx_cursor(&event.button.x, &event.button.y);
+		event.button.x += ceil(game_theme.scale * gamepad_mouse_shift(axis_x));
+		event.button.y += ceil(game_theme.scale * gamepad_mouse_shift(axis_y));
+		gfx_warp_cursor(event.button.x, event.button.y);
+		SDL_PushEvent(&event);
+	}
+	return interval;
+}
+
+static int gamepad_mouse_event(SDL_Event *ev)
+{
+	int rc = 0;
+	SDL_Event event;
+
+	memset(&event, 0, sizeof(event));
+	gfx_cursor(&event.button.x, &event.button.y);
+	event.type = SDL_MOUSEMOTION;
+	event.button.clicks = 1;
+	event.button.button = 1;
+
+	if (ev->type == SDL_CONTROLLERBUTTONDOWN) {
+		if (ev->cbutton.button != SDL_CONTROLLER_BUTTON_LEFTSTICK &&
+			ev->cbutton.button != SDL_CONTROLLER_BUTTON_RIGHTSTICK)
+			return 0;
+		event.type = SDL_MOUSEBUTTONDOWN;
+		rc = 1;
+	} else if (ev->type == SDL_CONTROLLERBUTTONUP) {
+		if (ev->cbutton.button != SDL_CONTROLLER_BUTTON_LEFTSTICK &&
+			ev->cbutton.button != SDL_CONTROLLER_BUTTON_RIGHTSTICK)
+			return 0;
+		event.type = SDL_MOUSEBUTTONUP;
+		rc = 1;
+	} else if (ev->type == SDL_CONTROLLERAXISMOTION) {
+		if (gamepad_timer == NULL_TIMER)
+			gamepad_timer = gfx_add_timer(GAMEPAD_TICKS, gamepad_timer_fn, NULL);
+	}
+	if (rc)
+		SDL_PushEvent(&event);
+	return rc;
+}
+
+static int gamepad_map(struct inp_event *inp)
+{
+	const char *key;
+	switch(inp->code) {
+	case SDL_CONTROLLER_BUTTON_DPAD_UP:
+		key = "up"; break;
+	case SDL_CONTROLLER_BUTTON_DPAD_DOWN:
+		key = "down"; break;
+	case SDL_CONTROLLER_BUTTON_DPAD_LEFT:
+		key = "left"; break;
+	case SDL_CONTROLLER_BUTTON_DPAD_RIGHT:
+		key = "right"; break;
+	case SDL_CONTROLLER_BUTTON_A: /* emulate click */
+		inp->type = (inp->type == KEY_DOWN)?MOUSE_DOWN:MOUSE_UP;
+		gfx_cursor(&inp->x, &inp->y);
+		inp->code = 1;
+		return 1;
+	case SDL_CONTROLLER_BUTTON_B:
+		key = "space"; break;
+	case SDL_CONTROLLER_BUTTON_X:
+		key = "tab"; break;
+	case SDL_CONTROLLER_BUTTON_Y:
+		key = "return"; break;
+	case SDL_CONTROLLER_BUTTON_START:
+		key = "escape"; break;
+	case SDL_CONTROLLER_BUTTON_LEFTSHOULDER:
+		key = "page up"; break;
+	case SDL_CONTROLLER_BUTTON_RIGHTSHOULDER:
+		key = "page down"; break;
+	default:
+		return 0;
+	}
+	strncpy(inp->sym, key, sizeof(inp->sym));
+	inp->sym[sizeof(inp->sym) - 1] = 0;
+	return 1;
 }
 
 int input_init(void)
@@ -318,6 +456,7 @@ int finger_pos(const char *finger, int *x, int *y, float *pressure)
 	}
 	return -1;
 }
+
 int input(struct inp_event *inp, int wait)
 {
 	int rc;
@@ -335,6 +474,9 @@ int input(struct inp_event *inp, int wait)
 	if (!rc)
 		return 0;
 
+	if (gamepad_mouse_event(&event))
+		return AGAIN;
+
 	inp->sym[0] = 0;
 	inp->type = 0;
 	inp->count = 1;
@@ -351,7 +493,7 @@ int input(struct inp_event *inp, int wait)
 		if (SDL_PeepEvents(&peek, 1, SDL_PEEKEVENT, event.type, event.type) > 0)
 			return AGAIN; /* to avoid flickering */
 #if defined(SAILFISHOS)
-		push_mouse_event(&event);
+		touch_mouse_event(&event);
 #endif
 		break;
 	case SDL_FINGERUP:
@@ -360,7 +502,7 @@ int input(struct inp_event *inp, int wait)
 #endif
 	case SDL_FINGERDOWN:
 #if defined(SAILFISHOS)
-		push_mouse_event(&event);
+		touch_mouse_event(&event);
 #endif
 #if defined(IOS) || defined(SAILFISHOS)
 		if (event.type == SDL_FINGERDOWN) {
@@ -395,14 +537,14 @@ int input(struct inp_event *inp, int wait)
 	case SDL_CONTROLLERBUTTONDOWN:
 		inp->type = KEY_DOWN;
 		inp->code = event.cbutton.button;
-		strncpy(inp->sym, gamepad_map(event.cbutton.button), sizeof(inp->sym));
-		inp->sym[sizeof(inp->sym) - 1] = 0;
+		if (!gamepad_map(inp))
+			return AGAIN;
 		break;
 	case SDL_CONTROLLERBUTTONUP:
 		inp->type = KEY_UP;
 		inp->code = event.cbutton.button;
-		strncpy(inp->sym, gamepad_map(event.cbutton.button), sizeof(inp->sym));
-		inp->sym[sizeof(inp->sym) - 1] = 0;
+		if (!gamepad_map(inp))
+			return AGAIN;
 		break;
 	case SDL_WINDOWEVENT:
 		switch (event.window.event) {
