@@ -71,8 +71,6 @@ static char *MAIN = NULL;
 
 #define STEAD_API_PATH instead_api_path
 
-#define ERR_MSG_MAX 512
-
 static struct list_head extensions = LIST_HEAD_INIT(extensions);
 
 #define for_each_extension(ext) list_for_each(&extensions, ext, list)
@@ -140,13 +138,9 @@ void instead_err_msg(const char *s)
 {
 	if (err_msg)
 		free(err_msg);
-	if (s) {
+	if (s)
 		err_msg = strdup(s);
-		if (err_msg && strlen(err_msg) > ERR_MSG_MAX) {
-			err_msg[ERR_MSG_MAX - 4] = 0;
-			strcat(err_msg, "...");
-		}
-	} else
+	else
 		err_msg = NULL;
 }
 
@@ -325,6 +319,17 @@ int instead_bretval(int n)
 	return lua_toboolean(L, n - N);
 }
 
+static int instead_bstatus(int n)
+{
+	int N;
+	if (!L)
+		return 0;
+	N = lua_gettop(L);  /* number of arguments */
+	if (n - N >= 0 || lua_isnil(L, n - N))
+		return 1;
+	return lua_toboolean(L, n - N);
+}
+
 int instead_iretval(int n)
 {
 	int N;
@@ -348,7 +353,7 @@ char *instead_file_cmd(char *s, int *rc)
 	instead_function("iface:cmd", args);
 	s = instead_retval(0);
 	if (rc)
-		*rc = !instead_bretval(1);
+		*rc = !instead_bstatus(1);
 	instead_clear();
 	extensions_hook(cmd);
 	return s;
@@ -370,7 +375,7 @@ char *instead_cmd(char *s, int *rc)
 	free(s);
 	s = instead_retval(0);
 	if (rc)
-		*rc = !instead_bretval(1);
+		*rc = !instead_bstatus(1);
 	instead_clear();
 	extensions_hook(cmd);
 	return s;
