@@ -1,13 +1,9 @@
 #ifndef __INSTEAD_EXTERNAL_H_
 #define __INSTEAD_EXTERNAL_H_
 
-#if defined (_WIN32_WCE) || defined(WINRT)
+#if defined(WINRT)
  #define errno 0
  #define putenv(a) ;
- #ifndef WINRT
- #define strerror(a) ""
- #define setlocale(a, b) ;
- #endif
 #endif
 
 #include <lua.h>
@@ -28,14 +24,10 @@
 #include <ctype.h>
 #include <dirent.h>
 #include <time.h>
-#ifndef S60
+#if !defined(PLAN9)
  #include <libgen.h>
+ #include <math.h>
 #endif
-#ifdef S60
- #include "snprintf.h"
- typedef long ssize_t;
-#endif
-#include <math.h>
 
 #ifndef PATH_MAX
 #define PATH_MAX 	4096
