@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2016 Peter Kosyh <p.kosyh at gmail.com>
+ * Copyright 2009-2018 Peter Kosyh <p.kosyh at gmail.com>
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation files
@@ -507,9 +507,9 @@ int game_change_hz(int hz)
 	if (!hz)
 		return -1;
 #ifndef __EMSCRIPTEN__
-	snd_done();
+	snd_close();
 	free_last_music();
-	snd_init(hz);
+	snd_open(hz);
 	snd_volume_mus(cur_vol);
 	sounds_reload();
 	game_music_player();
@@ -748,6 +748,7 @@ static void mus_callback(void *udata, unsigned char *stream, int len)
 	err:
 		snd_mus_callback(NULL, NULL);
 		luaL_unref(L, LUA_REGISTRYINDEX, callback_ref);
+		callback_ref = 0;
 	}
 	instead_clear();
 	instead_unlock();
@@ -757,16 +758,18 @@ static void mus_callback(void *udata, unsigned char *stream, int len)
 static int luaB_music_callback(lua_State *L) {
 	if (!sound_inited)
 		return 0;
+
+	snd_mus_callback(NULL, NULL);
+	if (callback_ref)
+		luaL_unref(L, LUA_REGISTRYINDEX, callback_ref);
+	callback_ref = 0;
+
 	if (lua_isfunction(L, 1)) {
 		game_stop_mus(0);
 		callback_ref = luaL_ref(L, LUA_REGISTRYINDEX);
 		snd_mus_callback(mus_callback, L);
-	} else {
-		snd_mus_callback(NULL, NULL);
-		if (callback_ref)
-			luaL_unref(L, LUA_REGISTRYINDEX, callback_ref);
-		callback_ref = 0;
 	}
+
 	return 0;
 }
 
@@ -795,7 +798,7 @@ static int sound_done(void)
 	}
 	game_stop_mus(0);
 	sounds_free();
-	snd_done();
+	snd_close();
 	sound_inited = 0;
 	return 0;
 }
@@ -858,9 +861,7 @@ static int sound_init(void)
 	rc = instead_loadfile(dirpath(path));
 	if (rc)
 		return rc;
-	if (sound_inited)
-		sound_done();
-	snd_init(opt_hz);
+	snd_open(opt_hz);
 	if (!nosound_sw)
 		game_change_vol(0, opt_vol);
 	sound_inited = 1;
