@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2020 Peter Kosyh <p.kosyh at gmail.com>
+ * Copyright 2009-2022 Peter Kosyh <p.kosyh at gmail.com>
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation files
@@ -22,7 +22,7 @@
  *
  */
 
-#if defined(__APPLE__) || defined(S60) || defined(ANDROID) || defined(WINRT)
+#if defined(__APPLE__) || defined(ANDROID) || defined(WINRT)
 #include <SDL.h>
 #endif
 
@@ -37,8 +37,8 @@
 #include "android.h"
 #endif
 
-#ifdef _WIN32_WCE
-extern void	libwince_init(const char* prog, int debug);
+#ifdef _WIN32
+#include <windows.h>
 #endif
 
 extern int debug_init(void);
@@ -62,6 +62,8 @@ int resizable_sw = 0;
 int scale_sw = 1;
 int standalone_sw = 0;
 int nocursor_sw = 0;
+int glhack_sw = 0;
+int dpi_sw = 0;
 
 static int opt_index = 1;
 
@@ -147,67 +149,40 @@ void macosx_init(void) {
 }
 #endif
 
-#ifdef _WIN32_WCE
-char *getcurdir(char *path)
-{
-	char *p;
-	if (path == NULL || *path == '\0')
-		return ".";
-	p = path + strlen(path) - 1;
-	while (*p == '/') {
-		if (p == path)
-			return path;
-		*p-- = '\0';
-	}
-	while (p >= path && *p != '/')
-		p--;
-	return p < path ? "." : p == path ? "/" : (*p = '\0', path);
-}
-void wince_init(char *path)
-{
-	unix_path(path);
-	strcpy(game_cwd, getcurdir(path));
-}
-#endif
 static int run_game(const char *path)
 {
-	char *p, *ep, *d;
-	static char gp[PATH_MAX + 1];
-	static char *cd = "./";
+	char *b, *d;
+	struct stat path_stat;
+	static char dir[PATH_MAX + 1];
+	static char base[PATH_MAX + 1];
 	if (!path)
 		return -1;
 	if (!path[0])
 		return -1;
 	if (strlen(path) >= PATH_MAX)
 		return -1;
-	strcpy(gp, path);
-	p = gp;
-	unix_path(p);
-	ep = p + strlen(p) - 1;
-	while (*ep == '/' && ep != p)
-		*ep-- = 0;
-	if (!p[0])
-		return -1;
-	ep = p + strlen(p) - 1;
-	while (ep != p) {
-		if (*ep == '/') {
-			*ep ++ = 0;
-			break;
-		}
-		ep --;
+	strcpy(dir, getrealpath(path, base)); /* always get full path */
+	unix_path(dir);
+	stat(dir, &path_stat);
+	if (S_ISREG(path_stat.st_mode) &&
+		(!strlowcmp(basename(dir), INSTEAD_MAIN) ||
+		!strlowcmp(basename(dir), INSTEAD_MAIN3))) {
+		d = dirname(dir);
+		strcpy(base, d);
+		d = dirname(d);
+	} else {
+		d = dirname(dir);
+		strcpy(base, path);
+		unix_path(base);
 	}
-	if (ep == p)
-		d = cd;
-	else
-		d = p;
-
-	if (!is_game(d, ep)) {
-		fprintf(stderr, "%s/%s is not a game path.\n", d, ep);
+	b = basename(base);
+	if (!is_game(d, b)) {
+		fprintf(stderr, "%s/%s is not a game path.\n", d, b);
 		return -1;
 	}
 	FREE(game_sw);
 	FREE(games_sw);
-	game_sw = strdup(ep);
+	game_sw = strdup(b);
 	games_sw = strdup(d);
 	return 0;
 }
@@ -231,10 +206,10 @@ static void usage(void)
 	"    -software\n        Force software rendering.\n"
 	"    -nopause\n        Do not pause the game on window minimize.\n"
 	"    -hinting 0|1|2|3\n        Set the font hinting mode (helpful with infinality)\n"
-	"    -install [game in zip]\n        Install game from zip archive\n"
+	"    -install [game in zip]\n        Install game from zip archive.\n"
 	"    -appdata [fullpath]\n        Store saves and settings in appdata path. Path must exist!\n"
 	"    -chunksize [size in bytes]\n        Size for audio buffer. Try this if sound lags.\n"
-	"    -vsync\n        Enable vsync display output (SDL2 only)\n");
+	"    -vsync\n        Enable vsync display output.\n");
 }
 static int profile_load(const char *path);
 extern int game_instead_extensions(void);
@@ -344,24 +319,36 @@ int instead_main(int argc, char *argv[])
 #endif
 	int err = 0;
 	int i;
+#if defined(_WIN32) && !defined(WINRT)
+	char *exe_path;
+	HINSTANCE lib = LoadLibrary("user32.dll");
+	int (*SetProcessDPIAware)() = (void*) GetProcAddress(lib, "SetProcessDPIAware");
+	if (SetProcessDPIAware)
+		SetProcessDPIAware();
+#endif
 #ifdef __APPLE__
 	macosx_init();
 #endif
-#ifndef S60
 	putenv("SDL_MOUSE_RELATIVE=0"); /* test this! */
+#if GTK_MAJOR_VERSION == 4 /* fix crash when SDL2 uses gl */
+	putenv("GDK_DEBUG=gl-disable");
 #endif
 
-#ifdef _WIN32_WCE
-	libwince_init(argv[0], 1);
-	wince_init(argv[0]);
+#if defined(APPIMAGE)
+	unix_path(argv[0]);
+	strcpy(game_cwd, dirname(argv[0]));
 #elif defined(WINRT)
 	unix_path(argv[0]);
-	strcpy(game_cwd, argv[0]);
-#elif defined(S60)
-	extern char s60_data[];
-	strcpy(game_cwd, s60_data);
+	strcpy(game_cwd, argv[0]); /* argv[0] is directory */
 #elif defined(_WIN32)
-	strcpy(game_cwd, dirname(argv[0]));
+	exe_path = malloc(PATH_MAX + 1);
+	if (exe_path) {
+		i = GetModuleFileName(NULL, exe_path, PATH_MAX);
+		exe_path[i] = 0;
+		strcpy(game_cwd, dirname(exe_path));
+		free(exe_path);
+	} else /* Sorry, kernel mode programming practice. Useless here. */
+		strcpy(game_cwd, dirname(argv[0]));
 #else
 	if (!getcwd(game_cwd, sizeof(game_cwd)))
 		fprintf(stderr,"Warning: can not get current dir\n.");
@@ -385,6 +372,11 @@ int instead_main(int argc, char *argv[])
 			vsync_sw = 1;
 		else if (!strcmp(argv[i], "-nosound"))
 			nosound_sw = 1;
+		else if (!strcmp(argv[i], "-dpi"))
+			if ((i + 1) < argc)
+				dpi_sw = atoi(argv[++i]);
+			else
+				dpi_sw = 96;
 		else if (!strcmp(argv[i], "-fullscreen"))
 			fullscreen_sw = 1;
 		else if (!strcmp(argv[i], "-hires"))
@@ -487,6 +479,11 @@ int instead_main(int argc, char *argv[])
 			nocursor_sw = 1;
 		} else if (!strcmp(argv[i], "-software")) {
 			software_sw = 1;
+		} else if (!strcmp(argv[i], "-glhack")) {
+			if ((i + 1) < argc)
+				glhack_sw = atoi(argv[++i]);
+			else
+				glhack_sw = 565; /* some samsung devices */
 		} else if (!strcmp(argv[i], "-resizable")) {
 			resizable_sw = 1;
 		} else if (!strcmp(argv[i], "-scale")) {
@@ -773,7 +770,11 @@ int instead_main(int argc, char *argv[])
 	snd_init(opt_hz);
 	snd_volume_mus(opt_vol);
 #ifdef _USE_GTK
+#if GTK_MAJOR_VERSION == 4
+	gtk_init();
+#else
 	gtk_init(&argc, &argv); /* must be called AFTER SDL_Init when using SDL2 */
+#endif
 #endif
 	if (gfx_video_init() || input_init())
 		return -1;
@@ -836,6 +837,7 @@ static struct parser profile_parser[] = {
 	{ "fontscale", parse_string, &fsize_sw, 0 },
 	{ "renderer", parse_string, &render_sw, 0 },
 	{ "nocursor", parse_int, &nocursor_sw, 0 },
+	{ "dpi", parse_int, &dpi_sw, 0 },
 	{ NULL, NULL, NULL, 0 },
 };
 
