@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2018 Peter Kosyh <p.kosyh at gmail.com>
+ * Copyright 2009-2022 Peter Kosyh <p.kosyh at gmail.com>
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation files
@@ -225,6 +225,35 @@ static int out_color(const void *v, char **out)
 	return 0;
 }
 
+int parse_dpi(const char *v, void *data)
+{
+	struct dpi *dpi = (struct dpi*)data;
+	if (sscanf(v, "%d-%d", &dpi->min, &dpi->max) != 2) {
+		if (sscanf(v, "%d", &dpi->min) != 1) {
+			dpi->min = DEFAULT_DPI_MIN;
+			dpi->max = DEFAULT_DPI_MAX;
+			return -1;
+		}
+		dpi->max = dpi->min;
+	}
+	return 0;
+}
+
+static int out_dpi(const void *v, char **out)
+{
+	char *o;
+	struct dpi *dpi = (struct dpi *)v;
+	o = malloc(64);
+	if (!o)
+		return -1;
+	if (dpi->min == dpi->max)
+		sprintf(o, "%d", dpi->min);
+	else
+		sprintf(o, "%d-%d", dpi->min, dpi->max);
+	*out = o;
+	return 0;
+}
+
 static int parse_include(const char *v, void *data)
 {
 	int rc;
@@ -271,10 +300,14 @@ static int theme_parse_full_path(const char *v, void *data)
 }
 
 struct parser cmd_parser[] = {
-	{ "scr.w", parse_int, &game_theme.w, 0 },
-	{ "scr.h", parse_int, &game_theme.h, 0 },
-	{ "scr.gfx.scalable", parse_int, &game_theme.gfx_scalable, CHANGED_WIN | CHANGED_INV | CHANGED_FONT | CHANGED_IFONT | CHANGED_MFONT },
+	{ "scr.w", parse_int, &game_theme.w, 0 }, /* must be 0 */
+	{ "scr.h", parse_int, &game_theme.h, 0 }, /* must be 1, see scale_aware logic */
+	{ "scr.scale_aware", parse_int, &game_theme.scale_aware, 0 },
+	{ "scr.dpi", parse_dpi, &game_theme.dpi, 0 },
+	{ "scr.gfx.scalable", parse_int, &game_theme.gfx_scalable, CHANGED_ALL },
+	{ "scr.gfx.scale", parse_float, &game_theme.img_scale, CHANGED_IMG },
 	{ "scr.col.bg", parse_color, &game_theme.bgcol, 0 },
+	{ "scr.col.brd", parse_color, &game_theme.brdcol, 0 },
 	{ "scr.gfx.icon", theme_parse_full_path, &game_theme.icon_name, CHANGED_ICON },
 	{ "scr.gfx.bg", theme_parse_full_path, &game_theme.bg_name, CHANGED_BG },
 	{ "scr.gfx.cursor.normal", theme_parse_full_path, &game_theme.cursor_name, CHANGED_CURSOR },
@@ -400,60 +433,7 @@ static theme_scalable_t theme_scalables[] = {
 };
 static int theme_scalables_unscaled[sizeof(theme_scalables)/sizeof(theme_scalable_t)];
 
-struct game_theme game_theme = {
-	.scale = 1.0f,
-	.w = 800,
-	.h = 480,
-	.gfx_scalable = 1,
-	.bg_name = NULL,
-	.bg = NULL,
-	.use_name = NULL,
-	.cursor_name = NULL,
-	.icon = NULL,
-	.icon_name = NULL,
-	.use = NULL,
-	.cursor = NULL,
-	.cur_x = 0,
-	.cur_y = 0,
-	.font_name = NULL,
-	.font_height = 1.0f,
-	.font = NULL,
-	.a_up_name = NULL,
-	.a_down_name = NULL,
-	.a_up = NULL,
-	.a_down = NULL,
-	.a_up_x = -1,
-	.a_up_y = -1,
-	.a_down_x = -1,
-	.a_down_y = -1,
-	.inv_font_name = NULL,
-	.inv_font = NULL,
-	.inv_font_height = 1.0f,
-	.inv_a_up_name = NULL,
-	.inv_a_down_name = NULL,
-	.inv_a_up_x = -1,
-	.inv_a_up_y = -1,
-	.inv_a_down_x = -1,
-	.inv_a_down_y = -1,
-	.inv_a_up = NULL,
-	.inv_a_down = NULL,
-	.menu_font_name = NULL,
-	.menu_font_height = 1.0f,
-	.menu_font = NULL,
-	.menu_button_name = NULL,
-	.menu_button = NULL,
-	.win_align = ALIGN_JUSTIFY,
-	.win_scroll_mode = 2,
-	.gfx_mode = GFX_MODE_EMBEDDED,
-	.inv_mode = INV_MODE_VERT | INV_ALIGN_SET(ALIGN_LEFT),
-	.ways_mode = ALIGN_TOP,
-	.click_name = NULL,
-	.click = NULL,
-	.xoff = 0,
-	.yoff = 0,
-	.changed = 0,
-};
-struct	game_theme game_theme;
+struct game_theme game_theme;
 
 static void free_theme_strings(void)
 {
@@ -527,9 +507,14 @@ int game_theme_free(void)
 }
 
 int theme_img_scale(img_t *p)
+{
+	return theme_gfx_scale(p, game_theme.img_scale);
+}
+
+int theme_gfx_scale(img_t *p, float scale)
 {
 	img_t pic;
-	float v = game_theme.scale;
+	float v = game_theme.scale * scale;
 	if (!p || !*p || v == 1.0f)
 		return 0;
 
@@ -551,6 +536,27 @@ static  int game_theme_scale(int w, int h)
 	int xoff, yoff;
 	struct game_theme *t = &game_theme;
 
+	if ((w < 0 || h < 0) && opt_hires) {
+		int ww = 0, hh = 0;
+		float dpi = gfx_get_dpi();
+		if (dpi > game_theme.dpi.max && game_theme.dpi.max > 0)
+			dpi = dpi / (float)game_theme.dpi.max;
+		else if (dpi < game_theme.dpi.min && game_theme.dpi.min > 0)
+			dpi = dpi / (float)game_theme.dpi.min;
+		else
+			dpi = 1.0f;
+		if ((SCALABLE_THEME || dpi > 1.0f) && !gfx_get_max_mode(&ww, &hh, MODE_ANY)) {
+			w = t->w * dpi; h = t->h * dpi;
+			xs = ys = dpi;
+			if (w > ww)
+				xs = (float)ww / (float)t->w;
+			if (h > hh)
+				ys = (float)hh / (float)t->h;
+			v = (xs < ys)?xs:ys;
+			w = t->w * v; h = t->h * v;
+			printf("DPI scale: %f\n", v);
+		}
+	}
 	if (w < 0 || h < 0 || (w == t->w && h == t->h)) {
 		t->scale = 1.0f;
 		t->xoff = 0;
@@ -602,12 +608,23 @@ out:
 		val *= t->scale;
 		if (theme_scalables[i].flags & TF_POSX)
 			val += t->xoff;
-  		if (theme_scalables[i].flags & TF_POSY)
+		if (theme_scalables[i].flags & TF_POSY)
 			val += t->yoff;
 		*(theme_scalables[i].val) = val;
 	}
 	t->w = w;
 	t->h = h;
+	if (t->scale_aware) {
+		if (t->scale_aware == 2) {
+			t->img_scale *= t->scale;
+			t->scale = 1.0f;
+		}
+		t->xoff = t->yoff = 0;
+		theme_scalables_unscaled[0] = w / t->scale;
+		theme_scalables_unscaled[1] = h / t->scale;
+		for (i = 2; theme_scalables[i].name; i++)
+			theme_scalables_unscaled[i] = *(theme_scalables[i].val) / t->scale;
+	}
 	return 0;
 }
 extern int parse_relative_path;
@@ -661,6 +678,10 @@ char *theme_getvar(char *name)
 			if (out_color(cmd_parser[i].p, &s))
 				return NULL;
 			return s;
+		} else if (cmd_parser[i].fn == parse_dpi) {
+			if (out_dpi(cmd_parser[i].p, &s))
+				return NULL;
+			return s;
 		} else
 			return NULL;
 		break;
@@ -732,7 +753,8 @@ static int theme_bg_scale(void)
 			if (!pic)
 				return -1;
 			screen = gfx_screen(pic);
-			gfx_img_fill(pic, 0, 0, t->w, t->h, gfx_col(0,0,0));
+			gfx_img_fill(pic, 0, 0, t->w, t->h,
+				gfx_col(t->brdcol.r, t->brdcol.g, t->brdcol.b));
 			gfx_copy(t->bg, xoff, yoff);
 			gfx_screen(screen);
 			gfx_free_image(t->bg);
@@ -792,7 +814,7 @@ static int game_theme_update_data(void)
 	}
 
 	if (t->menu_font_name && (t->changed & CHANGED_MFONT)) {
-		int m = FONT_SZ(t->inv_font_size);
+		int m = FONT_SZ(t->menu_font_size);
 		if (MAX_MENU_LINES * m * game_theme.menu_font_height > game_theme.h)
 			m = game_theme.h / MAX_MENU_LINES / game_theme.menu_font_height;
 		else if (m < t->menu_font_size)
@@ -993,9 +1015,10 @@ int game_theme_init(void)
 		game_theme_select(DEFAULT_THEME);
 		return -1;
 	}
-	gfx_bg(game_theme.bgcol);
-	if (!DIRECT_MODE)
-		game_clear_all();
+	gfx_bg(game_theme.xoff, game_theme.yoff,
+		game_theme.w - 2*game_theme.xoff, game_theme.h - 2*game_theme.yoff,
+		game_theme.bgcol, game_theme.brdcol);
+	game_clear_all();
 	gfx_flip();
 	gfx_commit();
 	return 0;
@@ -1390,6 +1413,8 @@ int game_theme_select(const char *name)
 int game_default_theme(void)
 {
 	int rc;
+	memset(&game_theme, 0, sizeof(game_theme));
+	game_theme.changed = CHANGED_ALL;
 	rc = game_theme_load(DEFAULT_THEME, THEME_GLOBAL);
 	if (rc)
 		return rc;
