@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2018 Peter Kosyh <p.kosyh at gmail.com>
+ * Copyright 2009-2021 Peter Kosyh <p.kosyh at gmail.com>
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation files
@@ -40,10 +40,17 @@
 
 struct game_theme {
 	float	scale;
-	int 	w;
-	int 	h;
+	float	img_scale;
+	int	scale_aware;
+	struct dpi {
+		int min;
+		int max;
+	} dpi;
+	int	w;
+	int	h;
 	int	gfx_scalable;
 	color_t	bgcol;
+	color_t brdcol;
 	char	*bg_name;
 	img_t	bg;
 	char	*use_name;
@@ -149,7 +156,11 @@ struct game_theme {
 #define CHANGED_IDOWN	0x1000
 #define CHANGED_BUTTON	0x2000
 #define CHANGED_ICON	0x4000
+#define CHANGED_IMG (CHANGED_BG | CHANGED_CLICK | CHANGED_CURSOR | CHANGED_USE | \
+	CHANGED_UP | CHANGED_DOWN | CHANGED_IUP |CHANGED_IDOWN | \
+	CHANGED_BUTTON)
 #define CHANGED_ALL 0xffff
+
 struct theme {
 	char *path;
 	char *name;
@@ -184,9 +195,10 @@ extern int 	game_theme_free(void);
 extern int	game_theme_optimize(void);
 extern int	game_theme_update(void);
 
-extern int 	theme_load(const char *name);
-extern int 	theme_load_idf(idf_t idf, const char *name);
-extern int 	theme_img_scale(img_t *p);
+extern int	theme_load(const char *name);
+extern int	theme_load_idf(idf_t idf, const char *name);
+extern int	theme_img_scale(img_t *p);
+extern int	theme_gfx_scale(img_t *p, float scale);
 extern int	theme_scalable_mode(int w, int h);
 
 extern int theme_relative;
@@ -216,4 +228,7 @@ extern int theme_relative;
 #define SCALABLE_THEME (game_theme.gfx_scalable & 3)
 #define SCALABLE_THEME_SMOOTH (game_theme.gfx_scalable & 1)
 
+#define DEFAULT_DPI_MIN 96
+#define DEFAULT_DPI_MAX 96
+
 #endif
