@@ -23,16 +23,6 @@ local type = std.type
 
 local dict = {}
 
-local function get_bool(o, nam)
-	if type(o[nam]) == 'boolean' then
-		return o[nam]
-	end
-	if type(o[nam]) == 'function' then
-		return o:nam()
-	end
-	return nil
-end
-
 instead.inv_delim = '\n'
 instead.hinv_delim = ' | '
 instead.ways_delim = ' | '
@@ -90,14 +80,15 @@ std.stat = std.class({
 	__stat_type = true;
 }, std.obj);
 
+-- luacheck: globals menu
 std.menu = std.class({
 	__menu_type = true;
-	new = function(self, v)
+	new = function(_, v)
 		if type(v) ~= 'table' then
 			std.err ("Wrong argument to std.menu:"..std.tostr(v), 2)
 		end
 		v = std.obj(v)
-		std.setmt(v, self)
+--		std.setmt(v, self)
 		return v
 	end;
 	inv = function(s, ...)
@@ -107,9 +98,13 @@ std.menu = std.class({
 		else
 			r, v = std.call(s, 'act', ...) -- fallback to act
 		end
-		return true, false -- menu mode
+		if not r and not v then
+			return true, false -- menu mode
+		end
+		return r, v
 	end;
 }, std.obj);
+
 std.setmt(std.phr, std.menu) -- make phrases menus
 std.setmt(std.ref '@', std.menu) -- make xact menu
 
@@ -331,14 +326,22 @@ end
 std.mod_init(function()
 	std.rawset(_G, 'instead', instead)
 end)
+
+local mp_hooked = false
+
 std.mod_start(function()
 	dict = {}
 	local mp = std.ref '@metaparser'
 	if mp then
 		mp.winsize = 0
 		mp.prompt = false
+		if not mp_hooked then -- force truncate text for all commands
+			std.mod_cmd(function(cmd) mp:trim() end)
+			mp_hooked = true
+		end
 	end
 end)
+
 std.mod_step(function(state)
 	if state then
 		dict = {}
