@@ -1,5 +1,5 @@
 /*
- * Copyright 2009-2018 Peter Kosyh <p.kosyh at gmail.com>
+ * Copyright 2009-2022 Peter Kosyh <p.kosyh at gmail.com>
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation files
@@ -87,11 +87,37 @@ char *find_in_esc(const char *l, const char *s)
 	return NULL;
 }
 
+static void unescape_sym(char *l, const char *s)
+{
+	int esc = 0;
+	char *r = l;
+	int d = 0;
+	for (; *l; ) {
+		if (esc) {
+			esc = 0;
+			if (strspn(l, s))
+				r --;
+			*r ++ = *l ++;
+			continue;
+		}
+		d = strcspn(l, s);
+		if (d)
+			memmove(r, l, d);
+		r += d; l += d;
+		if (*l == '\\')
+			esc = 1;
+		if (*l)
+			*r ++ = *l ++;
+	}
+	*r = 0;
+}
+
 static void comments_zap(char *p)
 {
 	char *l = find_in_esc(p, "\\;\n");
 	if (l)
 		*l = 0;
+	unescape_sym(p, "\\;\n");
 }
 
 int parse_all(void *fp, char *(*getl)(void *p, char *s, int size), const char *path, struct parser *cmd_parser)
@@ -290,7 +316,7 @@ int parse_path(const char *v, void *data)
 	unix_path(*p);
 	return 0;
 }
-#if defined(_WIN32) && !defined(_WIN32_WCE)
+#if defined(_WIN32) && !defined(WINRT)
 #include <wchar.h>
 #include <windows.h>
 
@@ -333,7 +359,7 @@ int parse_full_path(const char *v, void *data)
 		*p = strdup("");
 		return (*p)?0:-1;
 	}
-#if defined(_WIN32) && !defined(_WIN32_WCE)
+#if defined(_WIN32) && !defined(WINRT)
 	w32_getdir(cwd, sizeof(cwd));
 #else
 	getdir(cwd, sizeof(cwd));
